require 'spec_helper'

describe Flunkey::Metadata do

  it "parses single-line metadata" do
    m = Flunkey::Metadata.parse <<-END
        kMDItemCreator             = "PDFpen"
        kMDItemFSInvisible         = 0
        kMDItemFSNodeCount         = (null)
        kMDItemFSContentChangeDate = 2013-11-04 07:51:03 +0000
        END
    m.keys.size.should == 4
    m['kMDItemCreator'].should == 'PDFpen'
    m['kMDItemFSInvisible'].should == '0'
    m['kMDItemFSNodeCount'].should be_nil
    # treated as a date because the name ends in …Date
    m['kMDItemFSContentChangeDate'].should === DateTime.new(2013, 11, 4, 7, 51, 3, '+0')
  end

  it "parses array metadata" do
    m = Flunkey::Metadata.parse <<-END
        kMDItemContentTypeTree = (
            "public.data",
            "public.item"
        )
        END
    m.keys.size.should == 1
    m['kMDItemContentTypeTree'].should be_a Array
    m['kMDItemContentTypeTree'].should === %w{public.data public.item}
  end

  it "does the full format" do
    m = Flunkey::Metadata.parse <<-END
        kMDItemCreator     = "PDFpen"
        kMDItemContentTypeTree = (
            "public.data",
            "public.item"
        )
        kMDItemFSNodeCount = (null)
        END
    m.keys.size.should == 3
  end

end
